==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mk/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Корисникот го откажал барањето за средство на веб-страницата',
    'a_user_requested' => 'Корисникот побарал средство на веб-страницата',
    'accessory_name' => 'Име на додаток:',
    'additional_notes' => 'Дополнителни забелешки:',
    'admin_has_created' => 'Администраторот создаде сметка за вас на :web веб-страница.',
    'asset' => 'Основно средство:',
    'asset_name' => 'Име на основното средство:',
    'asset_requested' => 'Бараното основно средство',
    'asset_tag' => 'Код на основното средство:',
    'assigned_to' => 'Задолжен на',
    'best_regards' => 'Со почит,',
    'canceled' => 'Откажано:',
    'checkin_date' => 'Датум на раздолжување:',
    'checkout_date' => 'Датум на задолжување:',
    'click_to_confirm' => 'Ве молиме кликнете на следната врска за да ја потврдите вашата :web сметка:',
    'click_on_the_link_accessory' => 'Ве молиме кликнете на врската на дното за да потврдите дека сте го примиле додатокот.',
    'click_on_the_link_asset' => 'Ве молиме кликнете на врската на дното за да потврдите дека сте го примиле основното средство.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Тековна количина',
    'Days' => 'Денови',
    'days' => 'Денови',
    'expecting_checkin_date' => 'Очекуван датум на раздолжување:',
    'expires' => 'Истекува',
    'Expiring_Assets_Report' => 'Извештај за истекување на средства.',
    'Expiring_Licenses_Report' => 'Извештај за истекување на лиценци.',
    'hello' => 'Здраво',
    'hi' => 'Здраво',
    'i_have_read' => 'Ги прочитав и се согласив со условите за користење и го примив ова средство.',
    'item' => 'Средство:',
    'Item_Request_Canceled' => 'Барањето е откажано',
    'Item_Requested' => 'Побарана ставка',
    'link_to_update_password' => 'Ве молиме кликнете на следната врска за да ја обновите вашата :web лозинка:',
    'login_first_admin' => 'Влезете во новата инсталација на Snipe-IT користејќи ги ингеренциите подолу:',
    'login' => 'Најава:',
    'Low_Inventory_Report' => 'Извештај за низок инвентар',
    'min_QTY' => 'Минимална количина',
    'name' => 'Име',
    'new_item_checked' => 'Ново основно средство е задолжено на Ваше име, деталите се подолу.',
    'password' => 'Лозинка:',
    'password_reset' => 'Ресетирање на лозинка',

    'read_the_terms' => 'Ве молиме прочитајте ги условите за употреба подолу.',
    'read_the_terms_and_click' => 'Прочитајте ги условите за употреба подолу и кликнете на врската на дното за да потврдите дека ги прочитавте и се согласувате со условите за користење и сте ги добиле основните средства.',
    'requested' => 'Побарано:',
    'reset_link' => 'Вашата врска за ресетирање на лозинка',
    'reset_password' => 'За да ја ресетирате Вашата лозинка, притиснете на врската:',
    'serial' => 'Сериски',
    'supplier' => 'Добавувач',
    'tag' => 'Таг',
    'test_email' => 'Тест е-пошта од Snipe-IT',
    'test_mail_text' => 'Ова е тест од Snipe-IT Системот за управување со основни средства. Ако го добивте ова, е-поштата работи :)',
    'the_following_item' => 'Следната ставка е раздолжена: ',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'За да ја ресетирате вашата :web лозинка, пополнете го овој формулар:',
    'type' => 'Тип',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Корисник',
    'username' => 'Корисничко име',
    'welcome' => 'Добредојдовте :name',
    'welcome_to' => 'Добредојдовте на :web!',
    'your_credentials' => 'Вашите корисничко име и лозинка',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mk/mail.php <==
<?php

return [
    'a_user_canceled' => 'Корисникот го откажал барањето за средство на веб-страницата',
    'a_user_requested' => 'Корисникот побарал средство на веб-страницата',
    'accessory_name' => 'Име на додаток:',
    'additional_notes' => 'Дополнителни забелешки:',
    'admin_has_created' => 'Администраторот создаде сметка за вас на :web веб-страница.',
    'asset' => 'Основно средство:',
    'asset_name' => 'Име на основното средство:',
    'asset_requested' => 'Бараното основно средство',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Задолжен на',
    'best_regards' => 'Со почит,',
    'canceled' => 'Откажано:',
    'checkin_date' => 'Датум на раздолжување:',
    'checkout_date' => 'Датум на задолжување:',
    'click_to_confirm' => 'Ве молиме кликнете на следната врска за да ја потврдите вашата :web сметка:',
    'click_on_the_link_accessory' => 'Ве молиме кликнете на врската на дното за да потврдите дека сте го примиле додатокот.',
    'click_on_the_link_asset' => 'Ве молиме кликнете на врската на дното за да потврдите дека сте го примиле основното средство.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'Тековна количина',
    'Days' => 'Денови',
    'days' => 'Денови',
    'expecting_checkin_date' => 'Очекуван датум на раздолжување:',
    'expires' => 'Истекува',
    'Expiring_Assets_Report' => 'Извештај за истекување на средства.',
    'Expiring_Licenses_Report' => 'Извештај за истекување на лиценци.',
    'hello' => 'Здраво',
    'hi' => 'Здраво',
    'i_have_read' => 'Ги прочитав и се согласив со условите за користење и го примив ова средство.',
    'item' => 'Средство:',
    'Item_Request_Canceled' => 'Барањето е откажано',
    'Item_Requested' => 'Побарана ставка',
    'link_to_update_password' => 'Ве молиме кликнете на следната врска за да ја обновите вашата :web лозинка:',
    'login_first_admin' => 'Влезете во новата инсталација на Snipe-IT користејќи ги ингеренциите подолу:',
    'login' => 'Најава:',
    'Low_Inventory_Report' => 'Извештај за низок инвентар',
    'min_QTY' => 'Минимална количина',
    'name' => 'Име',
    'new_item_checked' => 'Ново основно средство е задолжено на Ваше име, деталите се подолу.',
    'password' => 'Лозинка:',
    'password_reset' => 'Ресетирање на лозинка',

    'read_the_terms' => 'Ве молиме прочитајте ги условите за употреба подолу.',
    'read_the_terms_and_click' => 'Прочитајте ги условите за употреба подолу и кликнете на врската на дното за да потврдите дека ги прочитавте и се согласувате со условите за користење и сте ги добиле основните средства.',
    'requested' => 'Побарано:',
    'reset_link' => 'Вашата врска за ресетирање на лозинка',
    'reset_password' => 'За да ја ресетирате Вашата лозинка, притиснете на врската:',
    'serial' => 'Сериски',
    'supplier' => 'Добавувач',
    'tag' => 'Таг',
    'test_email' => 'Тест е-пошта од Snipe-IT',
    'test_mail_text' => 'Ова е тест од Snipe-IT Системот за управување со основни средства. Ако го добивте ова, е-поштата работи :)',
    'the_following_item' => 'Следната ставка е раздолжена: ',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'За да ја ресетирате вашата :web лозинка, пополнете го овој формулар:',
    'type' => 'Тип',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Корисник',
    'username' => 'Корисничко име',
    'welcome' => 'Добредојдовте :name',
    'welcome_to' => 'Добредојдовте на :web!',
    'your_credentials' => 'Вашите корисничко име и лозинка',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
